**************************
sunkit-magex Documentation
**************************

This is the documentation for sunkit-magex.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installing
   generated/gallery/index
   reference/index
   performance
   numerical_methods_pfss/index.rst
   synoptic_fits
